==> paycenter-client-3.4.23-20230720.091828-2-sources.jar: cn/com/duiba/paycenter/dto/payment/charge/shenzhenumsunionpay/UnionPayUmsOrderResponseData.java <==
package cn.com.duiba.paycenter.dto.payment.charge.shenzhenumsunionpay;

/**
 * @author UnionPayUmsOrderResponseData
 * @Description
 * @date 2023/7/18 15:14
 */
public class UnionPayUmsOrderResponseData {
    private String errCode; // 平台错误码
    private String errMsg; // 平台错误信息
    private String msgId; // 消息ID
    private String srcReserve; // 请求系统预留字段
    private String responseTimestamp; // 报文响应时间 格式yyyy-MM-dd HH:mm:ss
    private String merName; // 商户名称
    private String merOrderId; // 商户订单号
    private String mid; // 商户号
    private String tid; // 终端号
    private String seqId; // 平台流水号
    private String settleRefId; // 清分ID 如果来源方传了bankRefId就等于bankRefId，否则等于seqId
    private String status; // 交易状态
    private int totalAmount; // 支付总金额
    private String targetOrderId; // 第三方订单号
    private String targetSys; // 目标平台代码 取值说明
    private String targetStatus; // 目标平台的状态
    private MiniPayRequest miniPayRequest; // 小程序支付用的请求报文，带有签名信息
    private String targetMid; // 支付渠道商户号 各渠道情况不同，酌情转换。
    private int yxlmAmount; // 营销联盟优惠金额 仅享受联盟优惠的订单，查询返回


    public class MiniPayRequest {
        // You can define the fields of the MiniPayRequest object here
    }

    public String getErrCode() {
        return errCode;
    }

    public void setErrCode(String errCode) {
        this.errCode = errCode;
    }

    public String getErrMsg() {
        return errMsg;
    }

    public void setErrMsg(String errMsg) {
        this.errMsg = errMsg;
    }

    public String getMsgId() {
        return msgId;
    }

    public void setMsgId(String msgId) {
        this.msgId = msgId;
    }

    public String getSrcReserve() {
        return srcReserve;
    }

    public void setSrcReserve(String srcReserve) {
        this.srcReserve = srcReserve;
    }

    public String getResponseTimestamp() {
        return responseTimestamp;
    }

    public void setResponseTimestamp(String responseTimestamp) {
        this.responseTimestamp = responseTimestamp;
    }

    public String getMerName() {
        return merName;
    }

    public void setMerName(String merName) {
        this.merName = merName;
    }

    public String getMerOrderId() {
        return merOrderId;
    }

    public void setMerOrderId(String merOrderId) {
        this.merOrderId = merOrderId;
    }

    public String getMid() {
        return mid;
    }

    public void setMid(String mid) {
        this.mid = mid;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getSeqId() {
        return seqId;
    }

    public void setSeqId(String seqId) {
        this.seqId = seqId;
    }

    public String getSettleRefId() {
        return settleRefId;
    }

    public void setSettleRefId(String settleRefId) {
        this.settleRefId = settleRefId;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public int getTotalAmount() {
        return totalAmount;
    }

    public void setTotalAmount(int totalAmount) {
        this.totalAmount = totalAmount;
    }

    public String getTargetOrderId() {
        return targetOrderId;
    }

    public void setTargetOrderId(String targetOrderId) {
        this.targetOrderId = targetOrderId;
    }

    public String getTargetSys() {
        return targetSys;
    }

    public void setTargetSys(String targetSys) {
        this.targetSys = targetSys;
    }

    public String getTargetStatus() {
        return targetStatus;
    }

    public void setTargetStatus(String targetStatus) {
        this.targetStatus = targetStatus;
    }

    public MiniPayRequest getMiniPayRequest() {
        return miniPayRequest;
    }

    public void setMiniPayRequest(MiniPayRequest miniPayRequest) {
        this.miniPayRequest = miniPayRequest;
    }

    public String getTargetMid() {
        return targetMid;
    }

    public void setTargetMid(String targetMid) {
        this.targetMid = targetMid;
    }

    public int getYxlmAmount() {
        return yxlmAmount;
    }

    public void setYxlmAmount(int yxlmAmount) {
        this.yxlmAmount = yxlmAmount;
    }
}

==> paycenter-client-3.5.33-sources.jar: cn/com/duiba/paycenter/dto/payment/charge/shenzhenumsunionpay/UnionPayUmsOrderResponseData.java <==
package cn.com.duiba.paycenter.dto.payment.charge.shenzhenumsunionpay;

import com.alibaba.fastjson.JSONObject;

import java.io.Serializable;

/**
 * @author UnionPayUmsOrderResponseData
 * @Description
 * @date 2023/7/18 15:14
 */
public class UnionPayUmsOrderResponseData implements Serializable {
    private String errCode; // 平台错误码

    private String errInfo; // 平台错误信息

    private String errMsg; // 平台错误信息
    private String msgId; // 消息ID
    private String srcReserve; // 请求系统预留字段
    private String responseTimestamp; // 报文响应时间 格式yyyy-MM-dd HH:mm:ss
    private String merName; // 商户名称
    private String merOrderId; // 商户订单号
    private String mid; // 商户号
    private String tid; // 终端号
    private String seqId; // 平台流水号
    private String settleRefId; // 清分ID 如果来源方传了bankRefId就等于bankRefId，否则等于seqId
    private String status; // 交易状态
    private int totalAmount; // 支付总金额
    private String targetOrderId; // 第三方订单号
    private String targetSys; // 目标平台代码 取值说明
    private String targetStatus; // 目标平台的状态
    private JSONObject miniPayRequest; // 小程序支付用的请求报文，带有签名信息
    private String targetMid; // 支付渠道商户号 各渠道情况不同，酌情转换。
    private int yxlmAmount; // 营销联盟优惠金额 仅享受联盟优惠的订单，查询返回
    public String getErrCode() {
        return errCode;
    }

    public void setErrCode(String errCode) {
        this.errCode = errCode;
    }

    public String getErrMsg() {
        return errMsg;
    }

    public void setErrMsg(String errMsg) {
        this.errMsg = errMsg;
    }

    public String getMsgId() {
        return msgId;
    }

    public void setMsgId(String msgId) {
        this.msgId = msgId;
    }

    public String getSrcReserve() {
        return srcReserve;
    }

    public void setSrcReserve(String srcReserve) {
        this.srcReserve = srcReserve;
    }

    public String getResponseTimestamp() {
        return responseTimestamp;
    }

    public void setResponseTimestamp(String responseTimestamp) {
        this.responseTimestamp = responseTimestamp;
    }

    public String getMerName() {
        return merName;
    }

    public void setMerName(String merName) {
        this.merName = merName;
    }

    public String getMerOrderId() {
        return merOrderId;
    }

    public void setMerOrderId(String merOrderId) {
        this.merOrderId = merOrderId;
    }

    public String getMid() {
        return mid;
    }

    public void setMid(String mid) {
        this.mid = mid;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getSeqId() {
        return seqId;
    }

    public void setSeqId(String seqId) {
        this.seqId = seqId;
    }

    public String getSettleRefId() {
        return settleRefId;
    }

    public void setSettleRefId(String settleRefId) {
        this.settleRefId = settleRefId;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public int getTotalAmount() {
        return totalAmount;
    }

    public void setTotalAmount(int totalAmount) {
        this.totalAmount = totalAmount;
    }

    public String getTargetOrderId() {
        return targetOrderId;
    }

    public void setTargetOrderId(String targetOrderId) {
        this.targetOrderId = targetOrderId;
    }

    public String getTargetSys() {
        return targetSys;
    }

    public void setTargetSys(String targetSys) {
        this.targetSys = targetSys;
    }

    public String getTargetStatus() {
        return targetStatus;
    }

    public void setTargetStatus(String targetStatus) {
        this.targetStatus = targetStatus;
    }


    public JSONObject getMiniPayRequest() {
        return miniPayRequest;
    }

    public void setMiniPayRequest(JSONObject miniPayRequest) {
        this.miniPayRequest = miniPayRequest;
    }

    public String getTargetMid() {
        return targetMid;
    }

    public void setTargetMid(String targetMid) {
        this.targetMid = targetMid;
    }

    public int getYxlmAmount() {
        return yxlmAmount;
    }

    public void setYxlmAmount(int yxlmAmount) {
        this.yxlmAmount = yxlmAmount;
    }

    public String getErrInfo() {
        return errInfo;
    }

    public void setErrInfo(String errInfo) {
        this.errInfo = errInfo;
    }
}
